@@ -1,4 +1,5 @@
-// Copyright (c) 2002 Rob Kaper <cap@capsi.com>
+// Copyright © 2002 Rob Kaper <cap@capsi.com>
+//             2010-2015 Sylvain Rochet <gradator@gradator.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -10,9 +11,8 @@
 // General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with this program; see the file COPYING.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// along with this program; see the file COPYING. If not, see
+// <http://www.gnu.org/licenses/>.
 
 #ifndef __MONOPD_DISPLAY_H__
 #define	__MONOPD_DISPLAY_H__
@@ -26,6 +26,7 @@ class DisplayButton
 {
 public:
 	DisplayButton(const std::string command, const std::string caption, const bool enabled);
+	DisplayButton(const DisplayButton *button);
 	const std::string command();
 	const std::string caption();
 	bool enabled();
@@ -39,25 +40,28 @@ class Display
 {
 public:
 	Display();
-	virtual ~Display();
+	Display(const Display *display);
+	~Display();
 
 	void setEstate(Estate *estate);
 	Estate *estate();
 	void setText(const std::string text);
+	void setText(const char *fmt, ...);
 	const std::string text();
 	void addButton(const std::string command, const std::string caption, const bool enabled);
 	void resetButtons();
-	void setClearText(bool clearText);
-	bool clearText();
-	void setClearButtons(bool clearButtons);
+	void resetText();
+	void resetEstate();
 	bool clearButtons();
+	bool clearText();
+	bool clearEstate();
 	std::vector<DisplayButton *> buttons();
 
 private:
 	Estate *m_estate;
 	std::string m_text;
 	std::vector<DisplayButton *> m_buttons;
-	bool m_clearText, m_clearButtons;
+	bool m_clearText, m_clearButtons, m_clearEstate;
 };
 
 
