@@ -85,8 +85,8 @@ class Game : public GameObject
 		unsigned int playerAssets(Player *player);
 
 		void updateTurn();
-		bool landPlayer(Player *pTurn, const bool directMove, const std::string &rentmath = "");
-		bool giveCard(Player *player, Card *card);
+		void landPlayer(Player *pTurn, const bool directMove, const std::string &rentmath = "");
+		void giveCard(Player *player, Card *card);
 		void declareBankrupt(Player *player);
 		void bankruptPlayer(Player *player);
 		void sendDisplayMsg(Display *display, Player *except = NULL);
@@ -105,7 +105,6 @@ class Game : public GameObject
 		Debt *findDebtByCreditor(Player *player);
 		void delDebt(Debt *);
 		void solveDebts(Player *player, const bool &verbose = false);
-		bool solveDebt(Debt *debt);
 		void enforceDebt(Player *pBroke, Debt *debt = 0);
 		void newAuction(Player *pInput);
 		Auction *auction();
@@ -163,10 +162,12 @@ private:
 	 */
 	GameObject *newConfigOption(const std::string &name, const std::string &description, bool editable);
 
+	bool solveDebt(Debt *debt);
+
 	Status m_status;
 	unsigned int m_nextCardGroupId, m_nextEstateId, m_nextEstateGroupId, m_nextTradeId, m_nextAuctionId;
 
-	Player *m_master, *m_pTurn, *m_pWinner;
+	Player *m_master, *m_pTurn;
 	Estate *m_goEstate;
 	int m_houses, m_hotels, m_startMoney;
 	bool m_isValid, m_pausedForDialog;
