@@ -15,6 +15,8 @@
 // along with this program; see the file COPYING. If not, see
 // <http://www.gnu.org/licenses/>.
 
+#include "config.h"
+
 #include <dirent.h>
 #include <netdb.h>
 #include <stdio.h>
@@ -32,7 +34,6 @@
 
 #include <string>
 
-#include "config.h"
 #include "socket.h"
 #include "auction.h"
 #include "event.h"
@@ -623,14 +624,14 @@ void MonopdServer::loadConfig()
 		return;
 	}
 
-	char str[1024], *buf;
+	char str[1024], *buf, *ret;
 
-	fgets(str, sizeof(str), f);
-	while(!feof(f))
-	{
-		if (str[0]=='#') {}
-		else if (strstr(str, "="))
-		{
+	for (ret = fgets(str, sizeof(str), f); ret && !feof(f); ret = fgets(str, sizeof(str), f)) {
+		if (str[0] == '#') {
+			continue;
+		}
+
+		if (strstr(str, "=")) {
 			buf = strtok(str, "=");
 			if (!strcmp(buf, "port"))
 				m_port = atoi(strtok(NULL, "\n\0"));
@@ -643,7 +644,6 @@ void MonopdServer::loadConfig()
 				m_useMetaserver = true;
 			}
 		}
-		fgets(str, sizeof(str), f);
 	}
 	fclose(f);
 }
@@ -663,7 +663,7 @@ void MonopdServer::loadGameTemplates()
 		exit(-1);
 	}
 	while ((direntp=readdir(dirp)) != NULL) {
-		char str[256], *buf;
+		char str[256], *buf, *ret;
 		std::string name, description;
 
 		if (!strstr(direntp->d_name, ".conf")) {
@@ -677,8 +677,8 @@ void MonopdServer::loadGameTemplates()
 			continue;
 		}
 
-		for (fgets(str, sizeof(str), f); !feof(f); fgets(str, sizeof(str), f)) {
-			if (str[0]=='#') {
+		for (ret = fgets(str, sizeof(str), f); ret && !feof(f); ret = fgets(str, sizeof(str), f)) {
+			if (str[0] == '#') {
 				continue;
 			}
 
@@ -687,8 +687,7 @@ void MonopdServer::loadGameTemplates()
 				goto abort;
 			}
 
-			if (strstr(str, "="))
-			{
+			if (strstr(str, "=")) {
 				buf = strtok(str, "=");
 				if (!strcmp(buf, "name"))
 					name = strtok(NULL, "\n\0");
